@@ -14,6 +14,7 @@ test_that("x cannot be missing", {
   expect_error(row_oneway_equalvar(), er)
   expect_error(row_oneway_welch(), er)
   expect_error(row_kruskalwallis(), er)
+  expect_error(row_waerden(), er)
   expect_error(row_bartlett(), er)
   expect_error(row_cor_pearson(), er)
   expect_error(row_ievora(), er)
@@ -43,6 +44,7 @@ test_that("groups cannot be missing", {
   expect_error(row_oneway_equalvar(x=NA), er)
   expect_error(row_oneway_welch(x=NA), er)
   expect_error(row_kruskalwallis(x=NA), er)
+  expect_error(row_waerden(x=NA), er)
   expect_error(row_bartlett(x=NA), er)
   expect_error(row_flignerkilleen(x=NA), er)
   expect_error(row_levene(x=NA), er)
@@ -74,6 +76,7 @@ test_that("x cannot be a character", {
   expect_error(row_oneway_equalvar(x=matX, g="a"), er)
   expect_error(row_oneway_welch(x=matX, g="a"), er)
   expect_error(row_kruskalwallis(x=matX, g="a"), er)
+  expect_error(row_waerden(x=matX, g="a"), er)
   expect_error(row_bartlett(x=matX, g="a"), er)
   expect_error(row_cor_pearson(x=matX, y=0), er)
   expect_error(row_ievora(x=matX, b="a"), er)
@@ -110,6 +113,7 @@ test_that("x cannot be partially numeric", {
   expect_error(row_oneway_equalvar(x=iris, g="a"), er)
   expect_error(row_oneway_welch(x=iris, g="a"), er)
   expect_error(row_kruskalwallis(x=iris, g="a"), er)
+  expect_error(row_waerden(x=iris, g="a"), er)
   expect_error(row_bartlett(x=iris, g="a"), er)
   expect_error(row_cor_pearson(x=iris, y=0), er)
   expect_error(row_ievora(x=iris, b="a"), er)
@@ -146,6 +150,7 @@ test_that("x cannot be complex", {
   expect_error(row_oneway_equalvar(x=matX, g="a"), er)
   expect_error(row_oneway_welch(x=matX, g="a"), er)
   expect_error(row_kruskalwallis(x=matX, g="a"), er)
+  expect_error(row_waerden(x=matX, g="a"), er)
   expect_error(row_bartlett(x=matX, g="a"), er)
   expect_error(row_cor_pearson(x=matX, y=0), er)
   expect_error(row_ievora(x=matX, b="a"), er)
@@ -183,6 +188,7 @@ test_that("x cannot be logical", {
   expect_error(row_oneway_equalvar(x=matX, g="a"), er)
   expect_error(row_oneway_welch(x=matX, g="a"), er)
   expect_error(row_kruskalwallis(x=matX, g="a"), er)
+  expect_error(row_waerden(x=matX, g="a"), er)
   expect_error(row_bartlett(x=matX, g="a"), er)
   expect_error(row_cor_pearson(x=matX, y=0), er)
   expect_error(row_ievora(x=matX, b="a"), er)
@@ -219,6 +225,7 @@ test_that("x cannot be NULL", {
   expect_error(row_oneway_equalvar(x=NULL, g="a"), er)
   expect_error(row_oneway_welch(x=NULL, g="a"), er)
   expect_error(row_kruskalwallis(x=NULL, g="a"), er)
+  expect_error(row_waerden(x=NULL, g="a"), er)
   expect_error(row_bartlett(x=NULL, g="a"), er)
   expect_error(row_cor_pearson(x=NULL, y=0), er)
   expect_error(row_ievora(x=NULL, b="a"), er)
@@ -255,6 +262,7 @@ test_that("x cannot be in a list", {
   expect_error(row_oneway_equalvar(x=list(1:5), g="a"), er)
   expect_error(row_oneway_welch(x=list(1:5), g="a"), er)
   expect_error(row_kruskalwallis(x=list(1:5), g="a"), er)
+  expect_error(row_waerden(x=list(1:5), g="a"), er)
   expect_error(row_bartlett(x=list(1:5), g="a"), er)
   expect_error(row_cor_pearson(x=list(1:5), y=0), er)
   expect_error(row_ievora(x=list(1:5), b="a"), er)
@@ -290,6 +298,7 @@ test_that("x cannot be a list", {
   expect_error(row_oneway_equalvar(x=as.list(1:5), g="a"), er)
   expect_error(row_oneway_welch(x=as.list(1:5), g="a"), er)
   expect_error(row_kruskalwallis(x=as.list(1:5), g="a"), er)
+  expect_error(row_waerden(x=as.list(1:5), g="a"), er)
   expect_error(row_bartlett(x=as.list(1:5), g="a"), er)
   expect_error(row_cor_pearson(x=as.list(1:5), y=0), er)
   expect_error(row_ievora(x=as.list(1:5), b="a"), er)
@@ -325,6 +334,7 @@ test_that("groups cannot be NULL", {
   expect_error(row_oneway_equalvar(x=matX, g=NULL), er)
   expect_error(row_oneway_welch(x=matX, g=NULL), er)
   expect_error(row_kruskalwallis(x=matX, g=NULL), er)
+  expect_error(row_waerden(x=matX, g=NULL), er)
   expect_error(row_bartlett(x=matX, g=NULL), er)
   expect_error(row_flignerkilleen(x=matX, g=NULL), er)
   expect_error(row_levene(x=matX, g=NULL), er)
@@ -337,6 +347,7 @@ test_that("groups cannot be a list", {
   expect_error(row_oneway_equalvar(x=matX, g=list(1:3)), er)
   expect_error(row_oneway_welch(x=matX, g=list(1:3)), er)
   expect_error(row_kruskalwallis(x=matX, g=list(1:3)), er)
+  expect_error(row_waerden(x=matX, g=list(1:3)), er)
   expect_error(row_bartlett(x=matX, g=list(1:3)), er)
   expect_error(row_flignerkilleen(x=matX, g=list(1:3)), er)
   expect_error(row_levene(x=matX, g=list(1:3)), er)
@@ -350,6 +361,7 @@ test_that("groups cannot be a matrix", {
   expect_error(row_oneway_equalvar(x=matX, g=grp), er)
   expect_error(row_oneway_welch(x=matX, g=grp), er)
   expect_error(row_kruskalwallis(x=matX, g=grp), er)
+  expect_error(row_waerden(x=matX, g=grp), er)
   expect_error(row_bartlett(x=matX, g=grp), er)
   expect_error(row_flignerkilleen(x=matX, g=grp), er)
   expect_error(row_levene(x=matX, g=grp), er)
@@ -447,6 +459,7 @@ test_that("group length matches number of columns", {
   expect_error(row_oneway_equalvar(x=matX, g=1:3), er)
   expect_error(row_oneway_welch(x=matX, g=1:3), er)
   expect_error(row_kruskalwallis(x=matX, g=1:3), er)
+  expect_error(row_waerden(x=matX, g=1:3), er)
   expect_error(row_bartlett(x=matX, g=1:3), er)
   expect_error(row_flignerkilleen(x=matX, g=1:3), er)
   expect_error(row_levene(x=matX, g=1:3), er)
