@@ -18,6 +18,7 @@ test_that("x and y can be numeric vectors", {
   expect_equal(row_oneway_equalvar(x=x, g=grp), row_oneway_equalvar(x=X, g=grp))
   expect_equal(row_oneway_welch(x=x, g=grp), row_oneway_welch(x=X, g=grp))
   expect_equal(row_kruskalwallis(x=x, g=grp), row_kruskalwallis(x=X, g=grp))
+  expect_equal(row_waerden(x=x, g=grp), row_waerden(x=X, g=grp))
   expect_equal(row_bartlett(x=x, g=grp), row_bartlett(x=X, g=grp))
   expect_equal(row_ievora(x=x, b=grp), row_ievora(x=X, b=grp))
   expect_equal(row_jarquebera(x=x), row_jarquebera(x=X))
@@ -44,6 +45,7 @@ test_that("x and y can be numeric data.frames", {
   expect_equal(row_oneway_equalvar(x=x, g=grp), row_oneway_equalvar(x=X, g=grp))
   expect_equal(row_oneway_welch(x=x, g=grp), row_oneway_welch(x=X, g=grp))
   expect_equal(row_kruskalwallis(x=x, g=grp), row_kruskalwallis(x=X, g=grp))
+  expect_equal(row_waerden(x=x, g=grp), row_waerden(x=X, g=grp))
   expect_equal(row_bartlett(x=x, g=grp), row_bartlett(x=X, g=grp))
   expect_equal(row_ievora(x=x, b=grp), row_ievora(x=X, b=grp))
   expect_equal(row_jarquebera(x=x), row_jarquebera(x=X))
@@ -70,6 +72,7 @@ test_that("x and y can have 0 rows and 0 columns", {
   expect_equal(nrow(row_oneway_equalvar(x=x, g=grp)), 0)
   expect_equal(nrow(row_oneway_welch(x=x, g=grp)), 0)
   expect_equal(nrow(row_kruskalwallis(x=x, g=grp)), 0)
+  expect_equal(nrow(row_waerden(x=x, g=grp)), 0)
   expect_equal(nrow(row_bartlett(x=x, g=grp)), 0)
   expect_equal(nrow(row_ievora(x=x, b=grp)), 0)
   expect_equal(nrow(row_jarquebera(x=x)), 0)
@@ -101,6 +104,7 @@ test_that("NA and NaN are treated the same", {
   expect_equal(row_oneway_equalvar(x=Xna, g=grp), row_oneway_equalvar(x=Xnan, g=grp))
   expect_equal(row_oneway_welch(x=Xna, g=grp), row_oneway_welch(x=Xnan, g=grp))
   expect_equal(row_kruskalwallis(x=Xna, g=grp), row_kruskalwallis(x=Xnan, g=grp))
+  expect_equal(row_waerden(x=Xna, g=grp), row_waerden(x=Xnan, g=grp))
   expect_equal(row_bartlett(x=Xna, g=grp), row_bartlett(x=Xnan, g=grp))
   expect_equal(row_ievora(x=Xna, b=grp), row_ievora(x=Xnan, b=grp))
   expect_equal(row_jarquebera(x=Xna), row_jarquebera(x=Xnan))
@@ -148,6 +152,8 @@ test_that("NA and NaN produce the same result", {
   expect_equal(suppressWarnings(row_oneway_welch(x=x, g=grp1)), suppressWarnings(row_oneway_welch(x=x, g=grp3)))
   expect_equal(suppressWarnings(row_kruskalwallis(x=x, g=grp1)), suppressWarnings(row_kruskalwallis(x=x, g=grp2)))
   expect_equal(suppressWarnings(row_kruskalwallis(x=x, g=grp1)), suppressWarnings(row_kruskalwallis(x=x, g=grp3)))
+  expect_equal(suppressWarnings(row_waerden(x=x, g=grp1)), suppressWarnings(row_waerden(x=x, g=grp2)))
+  expect_equal(suppressWarnings(row_waerden(x=x, g=grp1)), suppressWarnings(row_waerden(x=x, g=grp3)))
   expect_equal(suppressWarnings(row_bartlett(x=x, g=grp1)), suppressWarnings(row_bartlett(x=x, g=grp2)))
   expect_equal(suppressWarnings(row_bartlett(x=x, g=grp1)), suppressWarnings(row_bartlett(x=x, g=grp3)))
   expect_equal(suppressWarnings(row_ievora(x=x, b=grp1)), suppressWarnings(row_ievora(x=x, b=grp2)))
@@ -166,6 +172,7 @@ test_that("groups can all be NA", {
   expect_equal(suppressWarnings(row_oneway_equalvar(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_oneway_welch(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_kruskalwallis(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
+  expect_equal(suppressWarnings(row_waerden(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_bartlett(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_ievora(x=x, b=grp)$obs.0), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_flignerkilleen(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
@@ -179,6 +186,7 @@ test_that("groups can all be NaN", {
   expect_equal(suppressWarnings(row_oneway_equalvar(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_oneway_welch(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_kruskalwallis(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
+  expect_equal(suppressWarnings(row_waerden(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_bartlett(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_ievora(x=x, b=grp)$obs.0), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_flignerkilleen(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
@@ -192,6 +200,7 @@ test_that("all observations can be in the same group", {
   expect_equal(suppressWarnings(row_oneway_equalvar(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
   expect_equal(suppressWarnings(row_oneway_welch(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
   expect_equal(suppressWarnings(row_kruskalwallis(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
+  expect_equal(suppressWarnings(row_waerden(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
   expect_equal(suppressWarnings(row_bartlett(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
   expect_equal(suppressWarnings(row_ievora(x=x, b=grp)$obs.0), rep(ncol(x), nrow(x)))
   expect_equal(suppressWarnings(row_flignerkilleen(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
@@ -206,6 +215,7 @@ test_that("groups can be character", {
   expect_equal(row_oneway_equalvar(x=x, g=grp1), row_oneway_equalvar(x=x, g=grp2))
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
+  expect_equal(row_waerden(x=x, g=grp1), row_waerden(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
@@ -220,6 +230,7 @@ test_that("groups can be factor", {
   expect_equal(row_oneway_equalvar(x=x, g=grp1), row_oneway_equalvar(x=x, g=grp2))
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
+  expect_equal(row_waerden(x=x, g=grp1), row_waerden(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
@@ -234,6 +245,7 @@ test_that("groups can be logical", {
   expect_equal(row_oneway_equalvar(x=x, g=grp1), row_oneway_equalvar(x=x, g=grp2))
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
+  expect_equal(row_waerden(x=x, g=grp1), row_waerden(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
@@ -248,6 +260,7 @@ test_that("groups can be complex", {
   expect_equal(row_oneway_equalvar(x=x, g=grp1), row_oneway_equalvar(x=x, g=grp2))
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
+  expect_equal(row_waerden(x=x, g=grp1), row_waerden(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
@@ -262,6 +275,7 @@ test_that("groups can be a list", {
   expect_equal(row_oneway_equalvar(x=x, g=grp1), row_oneway_equalvar(x=x, g=grp2))
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
+  expect_equal(row_waerden(x=x, g=grp1), row_waerden(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
@@ -276,6 +290,7 @@ test_that("groups can be a matrix", {
   expect_equal(row_oneway_equalvar(x=x, g=grp1), row_oneway_equalvar(x=x, g=grp2))
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
+  expect_equal(row_waerden(x=x, g=grp1), row_waerden(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
@@ -290,6 +305,7 @@ test_that("groups can be infinite", {
   expect_equal(row_oneway_equalvar(x=x, g=grp1), row_oneway_equalvar(x=x, g=grp2))
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
+  expect_equal(row_waerden(x=x, g=grp1), row_waerden(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
   expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
   expect_equal(row_flignerkilleen(x=x, g=grp1), row_flignerkilleen(x=x, g=grp2))
